@@ -49,11 +49,11 @@
 //! }
 //! ```
 
+#![allow(clippy::eval_order_dependence)]
+
 extern crate proc_macro;
 
 use proc_macro::TokenStream;
-use proc_macro_error::*;
-use transform_context::TransformContext;
 
 const DERIVE_NAME: &str = "Arraygen";
 const DECL_FN_NAME: &str = "gen_array";
@@ -71,11 +71,11 @@ const IMPLICIT_SELECT_ALL_NAME: &str = "implicit_select_all";
 /// #[gen_array(?visibility fn your_method_name: YourReturnType)]
 /// ```
 ///
-/// * **?visibility**: This placeholder is optional. You can let it blank entirely. Or you can write `pub`, `pub(crate)` or any other pub variant.
+/// * **?visibility**: This placeholder is optional. You can let it blank entirely. Or you can write `pub`, `pub(crate)`, or any other pub variant.
 /// * **your_method_name**: This is meant to be any valid method name, following the standard rules. You can't use a name taken by another method in the struct impl. This restriction also includes other `Arraygen` methods.
-/// * **YourReturnType**: The return type can be any Rust type that can appear in a struct field. Notice that if the `type` does not implement the trait `Copy`, you are better returning `&type` or `&mut type` instead, in order to avoid ownership errors.
+/// * **YourReturnType**: The return type can be any Rust type that can appear in a struct field. Notice that if the `type` does not implement the trait `Copy`, you are better returning `&type` or `&mut type` instead, to avoid ownership errors.
 ///
-/// There is no limit in the number of methods you can declare.
+/// There is no limit to the number of methods you can declare.
 ///
 /// By default, these new `Arraygen` methods return arrays of length 0. That's not very useful, but that's why we also have the next attribute: `in_array`.
 ///
@@ -157,10 +157,50 @@ const IMPLICIT_SELECT_ALL_NAME: &str = "implicit_select_all";
 /// assert_eq!(numbers.primes(), [2, 3, 5]);
 /// ```
 ///
+/// Additionally, you may also add decorators to your `in_array` attribute.
+///
+/// ```ignore
+/// #[in_array(your_method_name { comma_separated_decorators })]
+/// ```
+///
+/// Possible decorators are:
+///
+/// * **cast** : This decorator casts the current field to the return type of the `gen_array` method where it will be included.
+/// * **unsafe_transmute** : This one uses [`unsafe { std::mem::transmute }`](https://doc.rust-lang.org/std/mem/fn.transmute.html) to force an unsafe cast of the current field to the return type of the `gen_array` method.
+/// * **override_implicit** : In case the current field is already selected by an `implicit_select_all` clause for this `gen_array` (more about this clause later), you may use `override_implicit` to apply different decorators to the current field.
+///
+/// Casting example:
+///
+/// ```rust
+/// # use arraygen::Arraygen;
+/// #[derive(Arraygen)]
+/// #[gen_array(fn all: i32)]
+/// struct Numbers {
+///     #[in_array(all { cast })]
+///     one: f32,
+///
+///     #[in_array(all { cast })]
+///     two: u8,
+///
+///     #[in_array(all { cast })]
+///     three: bool,
+/// }
+///
+/// let numbers = Numbers {
+///     one: 1.0,
+///     two: 1,
+///     three: true
+/// };
+///
+/// assert_eq!(numbers.all(), [1, 1, 1]);
+///
+/// ```
+///
+///
 ///
 /// # Trait Objects
 ///
-/// A very good use-case for `Arraygen` would be being able to extract Trait Objects from different concrete types, so you can operate in all of them at once.
+/// A very good use-case for `Arraygen` consists of extracting [Trait Objects](https://doc.rust-lang.org/reference/types/trait-object.html) from different concrete types, so you can operate in all of them at once.
 ///
 /// ```rust
 /// # use arraygen::Arraygen;
@@ -254,16 +294,18 @@ const IMPLICIT_SELECT_ALL_NAME: &str = "implicit_select_all";
 /// With ad-hoc traits and `Arraygen` is very easy to generalize common transformations with simple one-liners.
 ///
 ///
-/// # Implicitly selection Fields by their Types
+/// # Implicit selection of Fields by their Types
 ///
-/// You may omit entirely the `in_array` attribute if you use the `implicit_select_all` clause in your `gen_array` declarations.
+/// You may omit entirely the `in_array` attribute if you add the `implicit_select_all` clause at the end of your `gen_array` declarations.
 ///
 /// ```ignore
-/// #[gen_array(?visibility fn your_method_name: YourReturnType, implicit_select_all: MatchingFieldTypes)]
+/// #[gen_array(?visibility fn your_method_name: YourReturnType, implicit_select_all: Type1, Type2, Type3)]
 /// ```
 ///
-/// You may place either a single type in your `implicit_select_all` clause or a list of comma-separated types. 
+/// You may place either a single type in your `implicit_select_all` clause or a list of comma-separated types.
 /// 
+/// As an example, by adding "`implicit_select_all: f32`" to our `gen_array` method, we'll add all the fields that are of type `f32` in the current `struct`, as shown in the following code:
+///
 /// ```rust
 /// # use arraygen::Arraygen;
 /// #[derive(Arraygen)]
@@ -274,24 +316,79 @@ const IMPLICIT_SELECT_ALL_NAME: &str = "implicit_select_all";
 ///     pub tomato: f32,
 ///     pub chocolate: f32,
 /// }
-/// 
+///
 /// let prices = ImplicitPrices {
 ///     water: 2.0,
 ///     oil: 4.0,
 ///     tomato: 3.0,
 ///     chocolate: 5.0,
 /// };
-/// 
+///
 /// assert_eq!(prices.get_all_prices().iter().sum::<f32>(), 14.0);
 /// ```
 ///
+/// The `implicit_select_all` clause may also include decorators:
+/// ```ignore
+/// #[gen_array(?visibility fn your_method_name: YourReturnType, implicit_select_all { comma_separated_decorators }: MatchingFieldTypes)]
+/// ```
+///
+/// See which decorators you may use in the previous `in_array` section.
+///
+/// # Implicit selection of Fields with Type Wildcards
+///
+/// You may use *Type Wildcards* (`_`) on the `implicit_select_all` clause.
+///
+/// For example, the next expression will match all fields regardless of their type (this might be used in conjunction with decorators for casting between types):
+///
+/// ```ignore
+/// #[gen_array(fn all_fields: f32, implicit_select_all: _)]
+/// ```
+///
+/// *Type Wildcards* may also be used within a more complex *Type* definition, like `Option < _ >` or `Result < f32, _ >`.
+/// 
+/// Example:
+///
+/// ```rust
+/// # use arraygen::Arraygen;
+/// #[derive(Arraygen, Debug)]
+/// #[gen_array(fn options: &mut dyn ResetOption, implicit_select_all: Option<_>)]
+/// struct Options {
+///     pub a: Option<i32>,
+///     pub b: Option<bool>
+/// }
+///
+/// impl<T> ResetOption for Option<T> {
+///     fn reset(&mut self) {
+///         *self = None;
+///     }
+/// }
+
+/// trait ResetOption {
+///     fn reset(&mut self);
+/// }
+///
+/// let mut options = Options {
+///     a: Some(1),
+///     b: Some(true)
+/// };
+///
+/// options.options().iter_mut().for_each(|o| o.reset());
+/// assert_eq!(format!("{:?}", options), "Options { a: None, b: None }");
+/// ```
+/// 
+/// As you may see above, using *Type Wildcards* in conjuction with [Trait Objects](#trait-objects) allows you to accomplish very powerful constructs in a very succinct manner.
+///
 
-#[proc_macro_error]
 #[proc_macro_derive(Arraygen, attributes(gen_array, in_array))]
 pub fn arraygen(input: TokenStream) -> TokenStream {
-    TransformContext::new(input, DERIVE_NAME).transform_ast()
+    transform_context::transform_ast(input)
 }
 
-mod decl_fn_parsing;
-mod field_selector_parsing;
+mod parse_attribute;
+mod parse_decorator;
+mod parse_derive_arraygen;
+mod parse_gen_array;
+mod parse_in_array;
 mod transform_context;
+mod types;
+mod utils;
