@@ -5,5 +5,5 @@ extern crate arraygen;
 use arraygen::Arraygen;
 
 #[derive(Arraygen)]
-#[gen_array(pub my_array: i32)] //~ERROR 'gen_array' was used with the wrong syntax.
+#[gen_array(pub my_array: i32)] //~ERROR 8:17: 8:25: expected `fn`
 struct Empty{}
\ No newline at end of file
