@@ -7,6 +7,6 @@ use arraygen::Arraygen;
 #[derive(Arraygen)]
 #[gen_array(pub fn my_array: i32)]
 struct Test{
-    #[in_array(...)] //~ERROR 'in_array' was used with the wrong syntax.
+    #[in_array(...)] //~ERROR 10:16: 10:19: expected identifier
     foo: i32
 }
\ No newline at end of file
